@@ -1,6 +1,6 @@
 from .fields import VersionField
 from .version import Version
 
-default_app_config = "django_changes.apps.DjangoChangesConfig"
+default_app_config = "versionfield.apps.VersionFieldConfig"
 
 
